from distutils.core import setup
setup(
        name = 'kimolo',
        version = '1.0.0',
        py_modules = ['kimolo'],
        author = 'dankim',
        author_email = 'dankimist@gmail.com',
        url = 'http://www.fb.com/kinduberr',
        description = 'A simple printer of nested lists',
     )
